@@ -22,13 +22,10 @@ import sys
 
 import pkg_resources
 
-from zope.testrunner.profiling import available_profilers
-from zope.testrunner.formatter import (
-    OutputFormatter,
-    ColorfulOutputFormatter,
-    SubunitOutputFormatter,
-    )
+from zope.testrunner.formatter import ColorfulOutputFormatter
+from zope.testrunner.formatter import OutputFormatter
 from zope.testrunner.formatter import terminal_has_colors
+from zope.testrunner.profiling import available_profilers
 
 
 parser = optparse.OptionParser("Usage: %prog [options] [MODULE] [TEST]")
@@ -196,12 +193,6 @@ reporting.add_option(
 Colorize the output, but only when stdout is a terminal.
 """)
 
-reporting.add_option(
-    '--subunit', action="store_true", dest='subunit',
-    help="""\
-Use subunit output. Will not be colorized.
-""")
-
 reporting.add_option(
     '--slow-test', type='float', dest='slow_test_threshold', metavar='N',
     help="""\
@@ -577,19 +568,7 @@ def get_options(args=None, defaults=None):
         options.fail = True
         return options
 
-    if options.subunit:
-        try:
-            import subunit
-        except ImportError:
-            print("""\
-        Subunit is not installed. Please install Subunit
-        to generate subunit output.
-        """)
-            options.fail = True
-            return options
-        else:
-            options.output = SubunitOutputFormatter(options)
-    elif options.color:
+    if options.color:
         options.output = ColorfulOutputFormatter(options)
         options.output.slow_test_threshold = options.slow_test_threshold
     else:
